from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MessageDirection(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    MESSAGE_DIRECTION_UNSPECIFIED: _ClassVar[MessageDirection]
    MESSAGE_DIRECTION_CUSTOMER: _ClassVar[MessageDirection]
    MESSAGE_DIRECTION_BOT: _ClassVar[MessageDirection]
    MESSAGE_DIRECTION_ADMIN: _ClassVar[MessageDirection]
MESSAGE_DIRECTION_UNSPECIFIED: MessageDirection
MESSAGE_DIRECTION_CUSTOMER: MessageDirection
MESSAGE_DIRECTION_BOT: MessageDirection
MESSAGE_DIRECTION_ADMIN: MessageDirection

class SaveMessageRequest(_message.Message):
    __slots__ = ["chat_id", "content", "direction", "attachments", "date_time", "message_id"]
    CHAT_ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
    DATE_TIME_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    chat_id: int
    content: str
    direction: MessageDirection
    attachments: str
    date_time: str
    message_id: int
    def __init__(self, chat_id: _Optional[int] = ..., content: _Optional[str] = ..., direction: _Optional[_Union[MessageDirection, str]] = ..., attachments: _Optional[str] = ..., date_time: _Optional[str] = ..., message_id: _Optional[int] = ...) -> None: ...

class SaveMessageResponse(_message.Message):
    __slots__ = ["internal_id"]
    INTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    internal_id: str
    def __init__(self, internal_id: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DataType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    DATA_TYPE_UNSPECIFIED: _ClassVar[DataType]
    DATA_TYPE_FULL_NAME: _ClassVar[DataType]
    DATA_TYPE_BIRTH_PLACE: _ClassVar[DataType]
    DATA_TYPE_BIRTH_DATE_TIME: _ClassVar[DataType]
DATA_TYPE_UNSPECIFIED: DataType
DATA_TYPE_FULL_NAME: DataType
DATA_TYPE_BIRTH_PLACE: DataType
DATA_TYPE_BIRTH_DATE_TIME: DataType

class ValidationRequest(_message.Message):
    __slots__ = ["type", "input", "extra_prompt", "language"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    EXTRA_PROMPT_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    type: DataType
    input: str
    extra_prompt: str
    language: str
    def __init__(self, type: _Optional[_Union[DataType, str]] = ..., input: _Optional[str] = ..., extra_prompt: _Optional[str] = ..., language: _Optional[str] = ...) -> None: ...

class ValidationResponse(_message.Message):
    __slots__ = ["is_valid", "unified_result", "error_message"]
    IS_VALID_FIELD_NUMBER: _ClassVar[int]
    UNIFIED_RESULT_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    is_valid: bool
    unified_result: str
    error_message: str
    def __init__(self, is_valid: bool = ..., unified_result: _Optional[str] = ..., error_message: _Optional[str] = ...) -> None: ...

class ValidateSpreadQuestionRequest(_message.Message):
    __slots__ = ["input", "question_category", "language"]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    QUESTION_CATEGORY_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    input: str
    question_category: str
    language: str
    def __init__(self, input: _Optional[str] = ..., question_category: _Optional[str] = ..., language: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/bot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ftarot/bot.proto\x12\x05tarot\"L\n\rMessageAction\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x03url\x18\x02 \x01(\tH\x00\x12\x12\n\x08\x63\x61llback\x18\x03 \x01(\tH\x00\x42\t\n\x07payload\"\x87\x01\n\x12SendMessageRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\x12%\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x14.tarot.MessageAction\x12\x15\n\rrecipient_ids\x18\x03 \x03(\x03\x12\x15\n\x08hook_tag\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_hook_tag\"L\n\x11MessageSentStatus\x12\x14\n\x0crecipient_id\x18\x01 \x01(\x03\x12!\n\x06status\x18\x02 \x01(\x0e\x32\x11.tarot.SentStatus\"A\n\x13SendMessageResponse\x12*\n\x08statuses\x18\x01 \x03(\x0b\x32\x18.tarot.MessageSentStatus*\xa6\x01\n\x11MessageActionType\x12#\n\x1fMESSAGE_ACTION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17MESSAGE_ACTION_TYPE_URL\x10\x01\x12 \n\x1cMESSAGE_ACTION_TYPE_CALLBACK\x10\x02\x12-\n)MESSAGE_ACTION_TYPE_CALLBACK_PARAMETRIZED\x10\x03*t\n\nSentStatus\x12\x1b\n\x17SENT_STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10SENT_STATUS_SENT\x10\x01\x12\x15\n\x11SENT_STATUS_ERROR\x10\x02\x12\x1c\n\x18SENT_STATUS_USER_BLOCKED\x10\x03\x32T\n\nBotManager\x12\x46\n\x0bSendMessage\x12\x19.tarot.SendMessageRequest\x1a\x1a.tarot.SendMessageResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.bot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MESSAGEACTIONTYPE']._serialized_start=388
  _globals['_MESSAGEACTIONTYPE']._serialized_end=554
  _globals['_SENTSTATUS']._serialized_start=556
  _globals['_SENTSTATUS']._serialized_end=672
  _globals['_MESSAGEACTION']._serialized_start=26
  _globals['_MESSAGEACTION']._serialized_end=102
  _globals['_SENDMESSAGEREQUEST']._serialized_start=105
  _globals['_SENDMESSAGEREQUEST']._serialized_end=240
  _globals['_MESSAGESENTSTATUS']._serialized_start=242
  _globals['_MESSAGESENTSTATUS']._serialized_end=318
  _globals['_SENDMESSAGERESPONSE']._serialized_start=320
  _globals['_SENDMESSAGERESPONSE']._serialized_end=385
  _globals['_BOTMANAGER']._serialized_start=674
  _globals['_BOTMANAGER']._serialized_end=758
# @@protoc_insertion_point(module_scope)



from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MessageRole(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    MESSAGE_ROLE_UNSPECIFIED: _ClassVar[MessageRole]
    MESSAGE_ROLE_SYSTEM: _ClassVar[MessageRole]
    MESSAGE_ROLE_HUMAN: _ClassVar[MessageRole]
    MESSAGE_ROLE_AI: _ClassVar[MessageRole]
MESSAGE_ROLE_UNSPECIFIED: MessageRole
MESSAGE_ROLE_SYSTEM: MessageRole
MESSAGE_ROLE_HUMAN: MessageRole
MESSAGE_ROLE_AI: MessageRole

class TarotSpreadRequest(_message.Message):
    __slots__ = ["question", "category", "spread_profile_id", "language"]
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    SPREAD_PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    question: str
    category: str
    spread_profile_id: str
    language: str
    def __init__(self, question: _Optional[str] = ..., category: _Optional[str] = ..., spread_profile_id: _Optional[str] = ..., language: _Optional[str] = ...) -> None: ...

class TarotSpreadResponse(_message.Message):
    __slots__ = ["question", "category", "spread"]
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    SPREAD_FIELD_NUMBER: _ClassVar[int]
    question: str
    category: str
    spread: str
    def __init__(self, question: _Optional[str] = ..., category: _Optional[str] = ..., spread: _Optional[str] = ...) -> None: ...

class TarotSpreadConfigRequest(_message.Message):
    __slots__ = ["spread_profile_id", "category", "question", "language"]
    SPREAD_PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    spread_profile_id: str
    category: str
    question: str
    language: str
    def __init__(self, spread_profile_id: _Optional[str] = ..., category: _Optional[str] = ..., question: _Optional[str] = ..., language: _Optional[str] = ...) -> None: ...

class TarotSpreadConfigResponse(_message.Message):
    __slots__ = ["id", "spread_prompt"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SPREAD_PROMPT_FIELD_NUMBER: _ClassVar[int]
    id: str
    spread_prompt: str
    def __init__(self, id: _Optional[str] = ..., spread_prompt: _Optional[str] = ...) -> None: ...

class SpreadHistoryItem(_message.Message):
    __slots__ = ["content", "role", "timestamp"]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    content: str
    role: MessageRole
    timestamp: str
    def __init__(self, content: _Optional[str] = ..., role: _Optional[_Union[MessageRole, str]] = ..., timestamp: _Optional[str] = ...) -> None: ...

class SaveSpreadRequest(_message.Message):
    __slots__ = ["spread_profile_id", "spread", "question", "category", "language", "histories"]
    SPREAD_PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    SPREAD_FIELD_NUMBER: _ClassVar[int]
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    HISTORIES_FIELD_NUMBER: _ClassVar[int]
    spread_profile_id: str
    spread: str
    question: str
    category: str
    language: str
    histories: _containers.RepeatedCompositeFieldContainer[SpreadHistoryItem]
    def __init__(self, spread_profile_id: _Optional[str] = ..., spread: _Optional[str] = ..., question: _Optional[str] = ..., category: _Optional[str] = ..., language: _Optional[str] = ..., histories: _Optional[_Iterable[_Union[SpreadHistoryItem, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/spread.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tarot/spread.proto\x12\x05tarot\x1a\x1bgoogle/protobuf/empty.proto\"w\n\x12TarotSpreadRequest\x12\x10\n\x08question\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x19\n\x11spread_profile_id\x18\x03 \x01(\t\x12\x15\n\x08language\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language\"I\n\x13TarotSpreadResponse\x12\x10\n\x08question\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0e\n\x06spread\x18\x03 \x01(\t\"}\n\x18TarotSpreadConfigRequest\x12\x19\n\x11spread_profile_id\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08question\x18\x03 \x01(\t\x12\x15\n\x08language\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language\">\n\x19TarotSpreadConfigResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rspread_prompt\x18\x02 \x01(\t\"Y\n\x11SpreadHistoryItem\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12 \n\x04role\x18\x02 \x01(\x0e\x32\x12.tarot.MessageRole\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"\xb3\x01\n\x11SaveSpreadRequest\x12\x19\n\x11spread_profile_id\x18\x01 \x01(\t\x12\x0e\n\x06spread\x18\x02 \x01(\t\x12\x10\n\x08question\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\t\x12\x15\n\x08language\x18\x05 \x01(\tH\x00\x88\x01\x01\x12+\n\thistories\x18\x06 \x03(\x0b\x32\x18.tarot.SpreadHistoryItemB\x0b\n\t_language*q\n\x0bMessageRole\x12\x1c\n\x18MESSAGE_ROLE_UNSPECIFIED\x10\x00\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x01\x12\x16\n\x12MESSAGE_ROLE_HUMAN\x10\x02\x12\x13\n\x0fMESSAGE_ROLE_AI\x10\x03\x32\xfe\x01\n\x0bTarotReader\x12M\n\x12RequestTarotSpread\x12\x19.tarot.TarotSpreadRequest\x1a\x1a.tarot.TarotSpreadResponse\"\x00\x12V\n\x0fGetSpreadConfig\x12\x1f.tarot.TarotSpreadConfigRequest\x1a .tarot.TarotSpreadConfigResponse\"\x00\x12H\n\x12SaveCustomerSpread\x12\x18.tarot.SaveSpreadRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.spread_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MESSAGEROLE']._serialized_start=718
  _globals['_MESSAGEROLE']._serialized_end=831
  _globals['_TAROTSPREADREQUEST']._serialized_start=58
  _globals['_TAROTSPREADREQUEST']._serialized_end=177
  _globals['_TAROTSPREADRESPONSE']._serialized_start=179
  _globals['_TAROTSPREADRESPONSE']._serialized_end=252
  _globals['_TAROTSPREADCONFIGREQUEST']._serialized_start=254
  _globals['_TAROTSPREADCONFIGREQUEST']._serialized_end=379
  _globals['_TAROTSPREADCONFIGRESPONSE']._serialized_start=381
  _globals['_TAROTSPREADCONFIGRESPONSE']._serialized_end=443
  _globals['_SPREADHISTORYITEM']._serialized_start=445
  _globals['_SPREADHISTORYITEM']._serialized_end=534
  _globals['_SAVESPREADREQUEST']._serialized_start=537
  _globals['_SAVESPREADREQUEST']._serialized_end=716
  _globals['_TAROTREADER']._serialized_start=834
  _globals['_TAROTREADER']._serialized_end=1088
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from tarot import spread_pb2 as tarot_dot_spread__pb2


class TarotReaderStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RequestTarotSpread = channel.unary_unary(
                '/tarot.TarotReader/RequestTarotSpread',
                request_serializer=tarot_dot_spread__pb2.TarotSpreadRequest.SerializeToString,
                response_deserializer=tarot_dot_spread__pb2.TarotSpreadResponse.FromString,
                )
        self.GetSpreadConfig = channel.unary_unary(
                '/tarot.TarotReader/GetSpreadConfig',
                request_serializer=tarot_dot_spread__pb2.TarotSpreadConfigRequest.SerializeToString,
                response_deserializer=tarot_dot_spread__pb2.TarotSpreadConfigResponse.FromString,
                )
        self.SaveCustomerSpread = channel.unary_unary(
                '/tarot.TarotReader/SaveCustomerSpread',
                request_serializer=tarot_dot_spread__pb2.SaveSpreadRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class TarotReaderServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RequestTarotSpread(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSpreadConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveCustomerSpread(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TarotReaderServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RequestTarotSpread': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestTarotSpread,
                    request_deserializer=tarot_dot_spread__pb2.TarotSpreadRequest.FromString,
                    response_serializer=tarot_dot_spread__pb2.TarotSpreadResponse.SerializeToString,
            ),
            'GetSpreadConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSpreadConfig,
                    request_deserializer=tarot_dot_spread__pb2.TarotSpreadConfigRequest.FromString,
                    response_serializer=tarot_dot_spread__pb2.TarotSpreadConfigResponse.SerializeToString,
            ),
            'SaveCustomerSpread': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveCustomerSpread,
                    request_deserializer=tarot_dot_spread__pb2.SaveSpreadRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tarot.TarotReader', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TarotReader(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RequestTarotSpread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.TarotReader/RequestTarotSpread',
            tarot_dot_spread__pb2.TarotSpreadRequest.SerializeToString,
            tarot_dot_spread__pb2.TarotSpreadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSpreadConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.TarotReader/GetSpreadConfig',
            tarot_dot_spread__pb2.TarotSpreadConfigRequest.SerializeToString,
            tarot_dot_spread__pb2.TarotSpreadConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveCustomerSpread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.TarotReader/SaveCustomerSpread',
            tarot_dot_spread__pb2.SaveSpreadRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    TRANSACTION_TYPE_UNSPECIFIED: _ClassVar[TransactionType]
    TRANSACTION_TYPE_INCOME: _ClassVar[TransactionType]
    TRANSACTION_TYPE_OUTCOME: _ClassVar[TransactionType]

class TransactionStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    TRANSACTION_STATUS_UNSPECIFIED: _ClassVar[TransactionStatus]
    TRANSACTION_STATUS_SUCCESS: _ClassVar[TransactionStatus]
    TRANSACTION_STATUS_PENDING: _ClassVar[TransactionStatus]
    TRANSACTION_STATUS_FAILED: _ClassVar[TransactionStatus]
TRANSACTION_TYPE_UNSPECIFIED: TransactionType
TRANSACTION_TYPE_INCOME: TransactionType
TRANSACTION_TYPE_OUTCOME: TransactionType
TRANSACTION_STATUS_UNSPECIFIED: TransactionStatus
TRANSACTION_STATUS_SUCCESS: TransactionStatus
TRANSACTION_STATUS_PENDING: TransactionStatus
TRANSACTION_STATUS_FAILED: TransactionStatus

class TelegramUser(_message.Message):
    __slots__ = ["id", "username", "first_name", "last_name", "language_code", "is_bot", "is_premium", "profile_photos", "customer_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    IS_BOT_FIELD_NUMBER: _ClassVar[int]
    IS_PREMIUM_FIELD_NUMBER: _ClassVar[int]
    PROFILE_PHOTOS_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    username: str
    first_name: str
    last_name: str
    language_code: str
    is_bot: bool
    is_premium: bool
    profile_photos: _containers.RepeatedScalarFieldContainer[str]
    customer_id: str
    def __init__(self, id: _Optional[int] = ..., username: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., language_code: _Optional[str] = ..., is_bot: bool = ..., is_premium: bool = ..., profile_photos: _Optional[_Iterable[str]] = ..., customer_id: _Optional[str] = ...) -> None: ...

class SpreadProfile(_message.Message):
    __slots__ = ["tg_id", "spread_profile_id", "full_name", "birth_date", "birth_place", "zodiac_sign", "chinese_zodiac_sign", "gender"]
    TG_ID_FIELD_NUMBER: _ClassVar[int]
    SPREAD_PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    BIRTH_DATE_FIELD_NUMBER: _ClassVar[int]
    BIRTH_PLACE_FIELD_NUMBER: _ClassVar[int]
    ZODIAC_SIGN_FIELD_NUMBER: _ClassVar[int]
    CHINESE_ZODIAC_SIGN_FIELD_NUMBER: _ClassVar[int]
    GENDER_FIELD_NUMBER: _ClassVar[int]
    tg_id: int
    spread_profile_id: str
    full_name: str
    birth_date: str
    birth_place: str
    zodiac_sign: str
    chinese_zodiac_sign: str
    gender: str
    def __init__(self, tg_id: _Optional[int] = ..., spread_profile_id: _Optional[str] = ..., full_name: _Optional[str] = ..., birth_date: _Optional[str] = ..., birth_place: _Optional[str] = ..., zodiac_sign: _Optional[str] = ..., chinese_zodiac_sign: _Optional[str] = ..., gender: _Optional[str] = ...) -> None: ...

class GetCustomerRequest(_message.Message):
    __slots__ = ["customer_id", "tg_id", "spread_profile_id"]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    TG_ID_FIELD_NUMBER: _ClassVar[int]
    SPREAD_PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    tg_id: int
    spread_profile_id: str
    def __init__(self, customer_id: _Optional[str] = ..., tg_id: _Optional[int] = ..., spread_profile_id: _Optional[str] = ...) -> None: ...

class CreateCustomerRequest(_message.Message):
    __slots__ = ["tg_user"]
    TG_USER_FIELD_NUMBER: _ClassVar[int]
    tg_user: TelegramUser
    def __init__(self, tg_user: _Optional[_Union[TelegramUser, _Mapping]] = ...) -> None: ...

class CustomerLanguageRequest(_message.Message):
    __slots__ = ["language", "customer_id", "tg_id"]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    TG_ID_FIELD_NUMBER: _ClassVar[int]
    language: str
    customer_id: str
    tg_id: int
    def __init__(self, language: _Optional[str] = ..., customer_id: _Optional[str] = ..., tg_id: _Optional[int] = ...) -> None: ...

class CustomerProfile(_message.Message):
    __slots__ = ["id", "tg_user", "spread_profile", "actual_balance", "language"]
    ID_FIELD_NUMBER: _ClassVar[int]
    TG_USER_FIELD_NUMBER: _ClassVar[int]
    SPREAD_PROFILE_FIELD_NUMBER: _ClassVar[int]
    ACTUAL_BALANCE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    id: str
    tg_user: TelegramUser
    spread_profile: SpreadProfile
    actual_balance: int
    language: str
    def __init__(self, id: _Optional[str] = ..., tg_user: _Optional[_Union[TelegramUser, _Mapping]] = ..., spread_profile: _Optional[_Union[SpreadProfile, _Mapping]] = ..., actual_balance: _Optional[int] = ..., language: _Optional[str] = ...) -> None: ...

class CustomerBalance(_message.Message):
    __slots__ = ["id", "actual_balance"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ACTUAL_BALANCE_FIELD_NUMBER: _ClassVar[int]
    id: str
    actual_balance: int
    def __init__(self, id: _Optional[str] = ..., actual_balance: _Optional[int] = ...) -> None: ...

class CustomerTransaction(_message.Message):
    __slots__ = ["id", "customer_id", "type", "amount", "price", "currency", "description", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    type: TransactionType
    amount: int
    price: int
    currency: str
    description: str
    created_at: str
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., type: _Optional[_Union[TransactionType, str]] = ..., amount: _Optional[int] = ..., price: _Optional[int] = ..., currency: _Optional[str] = ..., description: _Optional[str] = ..., created_at: _Optional[str] = ...) -> None: ...

class CustomerTransactions(_message.Message):
    __slots__ = ["transactions"]
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    transactions: _containers.RepeatedCompositeFieldContainer[CustomerTransaction]
    def __init__(self, transactions: _Optional[_Iterable[_Union[CustomerTransaction, _Mapping]]] = ...) -> None: ...

class TopUpBalanceRequest(_message.Message):
    __slots__ = ["customer_id", "tg_id", "amount", "price", "currency", "payment_provider_transaction_id"]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    TG_ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_PROVIDER_TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    tg_id: int
    amount: int
    price: int
    currency: str
    payment_provider_transaction_id: str
    def __init__(self, customer_id: _Optional[str] = ..., tg_id: _Optional[int] = ..., amount: _Optional[int] = ..., price: _Optional[int] = ..., currency: _Optional[str] = ..., payment_provider_transaction_id: _Optional[str] = ...) -> None: ...

class InternalPurchaseRequest(_message.Message):
    __slots__ = ["customer_id", "tg_id"]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    TG_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    tg_id: int
    def __init__(self, customer_id: _Optional[str] = ..., tg_id: _Optional[int] = ...) -> None: ...

class CommitInternalPurchaseRequest(_message.Message):
    __slots__ = ["transaction_id"]
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    transaction_id: str
    def __init__(self, transaction_id: _Optional[str] = ...) -> None: ...

class RegisterReferralRequest(_message.Message):
    __slots__ = ["customer_id", "referrer_id"]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    REFERRER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    referrer_id: str
    def __init__(self, customer_id: _Optional[str] = ..., referrer_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/validation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16tarot/validation.proto\x12\x05tarot\"\x91\x01\n\x11ValidationRequest\x12\x1d\n\x04type\x18\x01 \x01(\x0e\x32\x0f.tarot.DataType\x12\r\n\x05input\x18\x02 \x01(\t\x12\x19\n\x0c\x65xtra_prompt\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08language\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_extra_promptB\x0b\n\t_language\"U\n\x12ValidationResponse\x12\x10\n\x08is_valid\x18\x01 \x01(\x08\x12\x16\n\x0eunified_result\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\"m\n\x1dValidateSpreadQuestionRequest\x12\r\n\x05input\x18\x01 \x01(\t\x12\x19\n\x11question_category\x18\x02 \x01(\t\x12\x15\n\x08language\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language*x\n\x08\x44\x61taType\x12\x19\n\x15\x44\x41TA_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x44\x41TA_TYPE_FULL_NAME\x10\x01\x12\x19\n\x15\x44\x41TA_TYPE_BIRTH_PLACE\x10\x02\x12\x1d\n\x19\x44\x41TA_TYPE_BIRTH_DATE_TIME\x10\x03\x32\xb0\x01\n\nValidation\x12\x45\n\x0cValidateData\x12\x18.tarot.ValidationRequest\x1a\x19.tarot.ValidationResponse\"\x00\x12[\n\x16ValidateSpreadQuestion\x12$.tarot.ValidateSpreadQuestionRequest\x1a\x19.tarot.ValidationResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.validation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DATATYPE']._serialized_start=379
  _globals['_DATATYPE']._serialized_end=499
  _globals['_VALIDATIONREQUEST']._serialized_start=34
  _globals['_VALIDATIONREQUEST']._serialized_end=179
  _globals['_VALIDATIONRESPONSE']._serialized_start=181
  _globals['_VALIDATIONRESPONSE']._serialized_end=266
  _globals['_VALIDATESPREADQUESTIONREQUEST']._serialized_start=268
  _globals['_VALIDATESPREADQUESTIONREQUEST']._serialized_end=377
  _globals['_VALIDATION']._serialized_start=502
  _globals['_VALIDATION']._serialized_end=678
# @@protoc_insertion_point(module_scope)



from tarot import bot_pb2 as _bot_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TaskStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    TASK_STATUS_UNSPECIFIED: _ClassVar[TaskStatus]
    TASK_STATUS_PENDING: _ClassVar[TaskStatus]
    TASK_STATUS_IN_PROGRESS: _ClassVar[TaskStatus]
    TASK_STATUS_COMPLETED: _ClassVar[TaskStatus]
    TASK_STATUS_FAILED: _ClassVar[TaskStatus]

class TaskType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    TASK_TYPE_UNSPECIFIED: _ClassVar[TaskType]
    TASK_TYPE_SEND_MESSAGE: _ClassVar[TaskType]
    TASK_TYPE_SEND_BATCH_MESSAGE: _ClassVar[TaskType]
TASK_STATUS_UNSPECIFIED: TaskStatus
TASK_STATUS_PENDING: TaskStatus
TASK_STATUS_IN_PROGRESS: TaskStatus
TASK_STATUS_COMPLETED: TaskStatus
TASK_STATUS_FAILED: TaskStatus
TASK_TYPE_UNSPECIFIED: TaskType
TASK_TYPE_SEND_MESSAGE: TaskType
TASK_TYPE_SEND_BATCH_MESSAGE: TaskType

class ScheduleTaskRequest(_message.Message):
    __slots__ = ["name", "type", "payload", "due_timestamp"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    DUE_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: TaskType
    payload: _bot_pb2.SendMessageRequest
    due_timestamp: int
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[TaskType, str]] = ..., payload: _Optional[_Union[_bot_pb2.SendMessageRequest, _Mapping]] = ..., due_timestamp: _Optional[int] = ...) -> None: ...

class ScheduleTaskResponse(_message.Message):
    __slots__ = ["id", "name", "due_date", "type", "status"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DUE_DATE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    due_date: str
    type: TaskType
    status: TaskStatus
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., due_date: _Optional[str] = ..., type: _Optional[_Union[TaskType, str]] = ..., status: _Optional[_Union[TaskStatus, str]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MessageActionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    MESSAGE_ACTION_TYPE_UNSPECIFIED: _ClassVar[MessageActionType]
    MESSAGE_ACTION_TYPE_URL: _ClassVar[MessageActionType]
    MESSAGE_ACTION_TYPE_CALLBACK: _ClassVar[MessageActionType]
    MESSAGE_ACTION_TYPE_CALLBACK_PARAMETRIZED: _ClassVar[MessageActionType]

class SentStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    SENT_STATUS_UNSPECIFIED: _ClassVar[SentStatus]
    SENT_STATUS_SENT: _ClassVar[SentStatus]
    SENT_STATUS_ERROR: _ClassVar[SentStatus]
    SENT_STATUS_USER_BLOCKED: _ClassVar[SentStatus]
MESSAGE_ACTION_TYPE_UNSPECIFIED: MessageActionType
MESSAGE_ACTION_TYPE_URL: MessageActionType
MESSAGE_ACTION_TYPE_CALLBACK: MessageActionType
MESSAGE_ACTION_TYPE_CALLBACK_PARAMETRIZED: MessageActionType
SENT_STATUS_UNSPECIFIED: SentStatus
SENT_STATUS_SENT: SentStatus
SENT_STATUS_ERROR: SentStatus
SENT_STATUS_USER_BLOCKED: SentStatus

class MessageAction(_message.Message):
    __slots__ = ["title", "url", "callback"]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    CALLBACK_FIELD_NUMBER: _ClassVar[int]
    title: str
    url: str
    callback: str
    def __init__(self, title: _Optional[str] = ..., url: _Optional[str] = ..., callback: _Optional[str] = ...) -> None: ...

class SendMessageRequest(_message.Message):
    __slots__ = ["message", "actions", "recipient_ids", "hook_tag"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ACTIONS_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_IDS_FIELD_NUMBER: _ClassVar[int]
    HOOK_TAG_FIELD_NUMBER: _ClassVar[int]
    message: str
    actions: _containers.RepeatedCompositeFieldContainer[MessageAction]
    recipient_ids: _containers.RepeatedScalarFieldContainer[int]
    hook_tag: str
    def __init__(self, message: _Optional[str] = ..., actions: _Optional[_Iterable[_Union[MessageAction, _Mapping]]] = ..., recipient_ids: _Optional[_Iterable[int]] = ..., hook_tag: _Optional[str] = ...) -> None: ...

class MessageSentStatus(_message.Message):
    __slots__ = ["recipient_id", "status"]
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    recipient_id: int
    status: SentStatus
    def __init__(self, recipient_id: _Optional[int] = ..., status: _Optional[_Union[SentStatus, str]] = ...) -> None: ...

class SendMessageResponse(_message.Message):
    __slots__ = ["statuses"]
    STATUSES_FIELD_NUMBER: _ClassVar[int]
    statuses: _containers.RepeatedCompositeFieldContainer[MessageSentStatus]
    def __init__(self, statuses: _Optional[_Iterable[_Union[MessageSentStatus, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BotRegion(_message.Message):
    __slots__ = ["id", "name", "languages"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LANGUAGES_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    languages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., languages: _Optional[_Iterable[str]] = ...) -> None: ...

class Bot(_message.Message):
    __slots__ = ["id", "name", "secret_token", "regions"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SECRET_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REGIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    secret_token: str
    regions: _containers.RepeatedCompositeFieldContainer[BotRegion]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., secret_token: _Optional[str] = ..., regions: _Optional[_Iterable[_Union[BotRegion, _Mapping]]] = ...) -> None: ...

class RetrieveBotsResponse(_message.Message):
    __slots__ = ["bots"]
    BOTS_FIELD_NUMBER: _ClassVar[int]
    bots: _containers.RepeatedCompositeFieldContainer[Bot]
    def __init__(self, bots: _Optional[_Iterable[_Union[Bot, _Mapping]]] = ...) -> None: ...

class BotRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/chats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11tarot/chats.proto\x12\x05tarot\"\xda\x01\n\x12SaveMessageRequest\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12*\n\tdirection\x18\x03 \x01(\x0e\x32\x17.tarot.MessageDirection\x12\x18\n\x0b\x61ttachments\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdate_time\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nmessage_id\x18\x06 \x01(\x03H\x02\x88\x01\x01\x42\x0e\n\x0c_attachmentsB\x0c\n\n_date_timeB\r\n\x0b_message_id\"*\n\x13SaveMessageResponse\x12\x13\n\x0binternal_id\x18\x01 \x01(\t*\x8d\x01\n\x10MessageDirection\x12!\n\x1dMESSAGE_DIRECTION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aMESSAGE_DIRECTION_CUSTOMER\x10\x01\x12\x19\n\x15MESSAGE_DIRECTION_BOT\x10\x02\x12\x1b\n\x17MESSAGE_DIRECTION_ADMIN\x10\x03\x32O\n\x05\x43hats\x12\x46\n\x0bSaveMessage\x12\x19.tarot.SaveMessageRequest\x1a\x1a.tarot.SaveMessageResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.chats_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MESSAGEDIRECTION']._serialized_start=294
  _globals['_MESSAGEDIRECTION']._serialized_end=435
  _globals['_SAVEMESSAGEREQUEST']._serialized_start=29
  _globals['_SAVEMESSAGEREQUEST']._serialized_end=247
  _globals['_SAVEMESSAGERESPONSE']._serialized_start=249
  _globals['_SAVEMESSAGERESPONSE']._serialized_end=291
  _globals['_CHATS']._serialized_start=437
  _globals['_CHATS']._serialized_end=516
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/bots_master.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tarot/bots_master.proto\x12\x05tarot\"8\n\tBotRegion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tlanguages\x18\x03 \x03(\t\"X\n\x03\x42ot\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0csecret_token\x18\x03 \x01(\t\x12!\n\x07regions\x18\x04 \x03(\x0b\x32\x10.tarot.BotRegion\"0\n\x14RetrieveBotsResponse\x12\x18\n\x04\x62ots\x18\x01 \x03(\x0b\x32\n.tarot.Bot\"\x18\n\nBotRequest\x12\n\n\x02id\x18\x01 \x01(\t2L\n\nBotsMaster\x12>\n\x0cRetrieveBots\x12\x11.tarot.BotRequest\x1a\x1b.tarot.RetrieveBotsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.bots_master_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BOTREGION']._serialized_start=34
  _globals['_BOTREGION']._serialized_end=90
  _globals['_BOT']._serialized_start=92
  _globals['_BOT']._serialized_end=180
  _globals['_RETRIEVEBOTSRESPONSE']._serialized_start=182
  _globals['_RETRIEVEBOTSRESPONSE']._serialized_end=230
  _globals['_BOTREQUEST']._serialized_start=232
  _globals['_BOTREQUEST']._serialized_end=256
  _globals['_BOTSMASTER']._serialized_start=258
  _globals['_BOTSMASTER']._serialized_end=334
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/users.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11tarot/users.proto\x12\x05tarot\x1a\x1bgoogle/protobuf/empty.proto\"\xbb\x01\n\x0cTelegramUser\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\x12\x15\n\rlanguage_code\x18\x06 \x01(\t\x12\x0e\n\x06is_bot\x18\x07 \x01(\x08\x12\x12\n\nis_premium\x18\x08 \x01(\x08\x12\x16\n\x0eprofile_photos\x18\t \x03(\t\x12\x13\n\x0b\x63ustomer_id\x18\n \x01(\t\"\xd0\x02\n\rSpreadProfile\x12\r\n\x05tg_id\x18\x01 \x01(\x03\x12\x1e\n\x11spread_profile_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tfull_name\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nbirth_date\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x62irth_place\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0bzodiac_sign\x18\x06 \x01(\tH\x04\x88\x01\x01\x12 \n\x13\x63hinese_zodiac_sign\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x13\n\x06gender\x18\x08 \x01(\tH\x06\x88\x01\x01\x42\x14\n\x12_spread_profile_idB\x0c\n\n_full_nameB\r\n\x0b_birth_dateB\x0e\n\x0c_birth_placeB\x0e\n\x0c_zodiac_signB\x16\n\x14_chinese_zodiac_signB\t\n\x07_gender\"\x92\x01\n\x12GetCustomerRequest\x12\x18\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05tg_id\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x1e\n\x11spread_profile_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x08\n\x06_tg_idB\x14\n\x12_spread_profile_id\"=\n\x15\x43reateCustomerRequest\x12$\n\x07tg_user\x18\x01 \x01(\x0b\x32\x13.tarot.TelegramUser\"Y\n\x17\x43ustomerLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x15\n\x0b\x63ustomer_id\x18\x02 \x01(\tH\x00\x12\x0f\n\x05tg_id\x18\x03 \x01(\x03H\x00\x42\x04\n\x02id\"\xfa\x01\n\x0f\x43ustomerProfile\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12)\n\x07tg_user\x18\x02 \x01(\x0b\x32\x13.tarot.TelegramUserH\x01\x88\x01\x01\x12\x31\n\x0espread_profile\x18\x03 \x01(\x0b\x32\x14.tarot.SpreadProfileH\x02\x88\x01\x01\x12\x1b\n\x0e\x61\x63tual_balance\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x15\n\x08language\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_tg_userB\x11\n\x0f_spread_profileB\x11\n\x0f_actual_balanceB\x0b\n\t_language\"5\n\x0f\x43ustomerBalance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x63tual_balance\x18\x02 \x01(\x05\"\xb6\x01\n\x13\x43ustomerTransaction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.tarot.TransactionType\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x05\x12\r\n\x05price\x18\x05 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\"H\n\x14\x43ustomerTransactions\x12\x30\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x1a.tarot.CustomerTransaction\"\xc6\x01\n\x13TopUpBalanceRequest\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x0f\n\x05tg_id\x18\x02 \x01(\x03H\x00\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x05\x12\r\n\x05price\x18\x04 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12,\n\x1fpayment_provider_transaction_id\x18\x06 \x01(\tH\x01\x88\x01\x01\x42\x04\n\x02idB\"\n _payment_provider_transaction_id\"G\n\x17InternalPurchaseRequest\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x0f\n\x05tg_id\x18\x02 \x01(\x03H\x00\x42\x04\n\x02id\"7\n\x1d\x43ommitInternalPurchaseRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\"C\n\x17RegisterReferralRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x13\n\x0breferrer_id\x18\x02 \x01(\t*n\n\x0fTransactionType\x12 \n\x1cTRANSACTION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17TRANSACTION_TYPE_INCOME\x10\x01\x12\x1c\n\x18TRANSACTION_TYPE_OUTCOME\x10\x02*\x96\x01\n\x11TransactionStatus\x12\"\n\x1eTRANSACTION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTRANSACTION_STATUS_SUCCESS\x10\x01\x12\x1e\n\x1aTRANSACTION_STATUS_PENDING\x10\x02\x12\x1d\n\x19TRANSACTION_STATUS_FAILED\x10\x03\x32\xea\x08\n\x05Users\x12\x46\n\x0e\x43reateCustomer\x12\x1c.tarot.CreateCustomerRequest\x1a\x16.tarot.CustomerProfile\x12@\n\x0bGetCustomer\x12\x19.tarot.GetCustomerRequest\x1a\x16.tarot.CustomerProfile\x12P\n\x16UpdateCustomerLanguage\x12\x1e.tarot.CustomerLanguageRequest\x1a\x16.tarot.CustomerProfile\x12>\n\x12\x43reateTelegramUser\x12\x13.tarot.TelegramUser\x1a\x13.tarot.TelegramUser\x12\x41\n\x0fGetTelegramUser\x12\x19.tarot.GetCustomerRequest\x1a\x13.tarot.TelegramUser\x12>\n\x12UpdateTelegramUser\x12\x13.tarot.TelegramUser\x1a\x13.tarot.TelegramUser\x12\x41\n\x13UpdateSpreadProfile\x12\x14.tarot.SpreadProfile\x1a\x14.tarot.SpreadProfile\x12\x43\n\x10GetSpreadProfile\x12\x19.tarot.GetCustomerRequest\x1a\x14.tarot.SpreadProfile\x12G\n\x12GetCustomerBalance\x12\x19.tarot.GetCustomerRequest\x1a\x16.tarot.CustomerBalance\x12Q\n\x17GetCustomerTransactions\x12\x19.tarot.GetCustomerRequest\x1a\x1b.tarot.CustomerTransactions\x12\x42\n\x0cTopUpBalance\x12\x1a.tarot.TopUpBalanceRequest\x1a\x16.tarot.CustomerBalance\x12V\n\x18InitiateInternalPurchase\x12\x1e.tarot.InternalPurchaseRequest\x1a\x1a.tarot.CustomerTransaction\x12Z\n\x16\x43ommitInternalPurchase\x12$.tarot.CommitInternalPurchaseRequest\x1a\x1a.tarot.CustomerTransaction\x12Z\n\x16RevertInternalPurchase\x12$.tarot.CommitInternalPurchaseRequest\x1a\x1a.tarot.CustomerTransaction\x12J\n\x10RegisterReferral\x12\x1e.tarot.RegisterReferralRequest\x1a\x16.google.protobuf.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.users_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRANSACTIONTYPE']._serialized_start=1856
  _globals['_TRANSACTIONTYPE']._serialized_end=1966
  _globals['_TRANSACTIONSTATUS']._serialized_start=1969
  _globals['_TRANSACTIONSTATUS']._serialized_end=2119
  _globals['_TELEGRAMUSER']._serialized_start=58
  _globals['_TELEGRAMUSER']._serialized_end=245
  _globals['_SPREADPROFILE']._serialized_start=248
  _globals['_SPREADPROFILE']._serialized_end=584
  _globals['_GETCUSTOMERREQUEST']._serialized_start=587
  _globals['_GETCUSTOMERREQUEST']._serialized_end=733
  _globals['_CREATECUSTOMERREQUEST']._serialized_start=735
  _globals['_CREATECUSTOMERREQUEST']._serialized_end=796
  _globals['_CUSTOMERLANGUAGEREQUEST']._serialized_start=798
  _globals['_CUSTOMERLANGUAGEREQUEST']._serialized_end=887
  _globals['_CUSTOMERPROFILE']._serialized_start=890
  _globals['_CUSTOMERPROFILE']._serialized_end=1140
  _globals['_CUSTOMERBALANCE']._serialized_start=1142
  _globals['_CUSTOMERBALANCE']._serialized_end=1195
  _globals['_CUSTOMERTRANSACTION']._serialized_start=1198
  _globals['_CUSTOMERTRANSACTION']._serialized_end=1380
  _globals['_CUSTOMERTRANSACTIONS']._serialized_start=1382
  _globals['_CUSTOMERTRANSACTIONS']._serialized_end=1454
  _globals['_TOPUPBALANCEREQUEST']._serialized_start=1457
  _globals['_TOPUPBALANCEREQUEST']._serialized_end=1655
  _globals['_INTERNALPURCHASEREQUEST']._serialized_start=1657
  _globals['_INTERNALPURCHASEREQUEST']._serialized_end=1728
  _globals['_COMMITINTERNALPURCHASEREQUEST']._serialized_start=1730
  _globals['_COMMITINTERNALPURCHASEREQUEST']._serialized_end=1785
  _globals['_REGISTERREFERRALREQUEST']._serialized_start=1787
  _globals['_REGISTERREFERRALREQUEST']._serialized_end=1854
  _globals['_USERS']._serialized_start=2122
  _globals['_USERS']._serialized_end=3252
# @@protoc_insertion_point(module_scope)



import json
from setuptools import setup, find_packages

DESCRIPTION = 'A package with gRPC generated code'
LONG_DESCRIPTION = 'A package with gRPC generated code of the tarot services'

version = json.load(open('package.json'))['version']

# Setting up
setup(
    name="tarot_contracts",
    version=version,
    author="Vlad Balabash",
    author_email="<vladb951@gmail.com>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    package_data={
        '': ['*.pyi']
    },
    install_requires=[],
    keywords=['python', 'grpc', 'tarotbot'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from tarot import users_pb2 as tarot_dot_users__pb2


class UsersStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateCustomer = channel.unary_unary(
                '/tarot.Users/CreateCustomer',
                request_serializer=tarot_dot_users__pb2.CreateCustomerRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerProfile.FromString,
                )
        self.GetCustomer = channel.unary_unary(
                '/tarot.Users/GetCustomer',
                request_serializer=tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerProfile.FromString,
                )
        self.UpdateCustomerLanguage = channel.unary_unary(
                '/tarot.Users/UpdateCustomerLanguage',
                request_serializer=tarot_dot_users__pb2.CustomerLanguageRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerProfile.FromString,
                )
        self.CreateTelegramUser = channel.unary_unary(
                '/tarot.Users/CreateTelegramUser',
                request_serializer=tarot_dot_users__pb2.TelegramUser.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.GetTelegramUser = channel.unary_unary(
                '/tarot.Users/GetTelegramUser',
                request_serializer=tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.UpdateTelegramUser = channel.unary_unary(
                '/tarot.Users/UpdateTelegramUser',
                request_serializer=tarot_dot_users__pb2.TelegramUser.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.UpdateSpreadProfile = channel.unary_unary(
                '/tarot.Users/UpdateSpreadProfile',
                request_serializer=tarot_dot_users__pb2.SpreadProfile.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.SpreadProfile.FromString,
                )
        self.GetSpreadProfile = channel.unary_unary(
                '/tarot.Users/GetSpreadProfile',
                request_serializer=tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.SpreadProfile.FromString,
                )
        self.GetCustomerBalance = channel.unary_unary(
                '/tarot.Users/GetCustomerBalance',
                request_serializer=tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerBalance.FromString,
                )
        self.GetCustomerTransactions = channel.unary_unary(
                '/tarot.Users/GetCustomerTransactions',
                request_serializer=tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerTransactions.FromString,
                )
        self.TopUpBalance = channel.unary_unary(
                '/tarot.Users/TopUpBalance',
                request_serializer=tarot_dot_users__pb2.TopUpBalanceRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerBalance.FromString,
                )
        self.InitiateInternalPurchase = channel.unary_unary(
                '/tarot.Users/InitiateInternalPurchase',
                request_serializer=tarot_dot_users__pb2.InternalPurchaseRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerTransaction.FromString,
                )
        self.CommitInternalPurchase = channel.unary_unary(
                '/tarot.Users/CommitInternalPurchase',
                request_serializer=tarot_dot_users__pb2.CommitInternalPurchaseRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerTransaction.FromString,
                )
        self.RevertInternalPurchase = channel.unary_unary(
                '/tarot.Users/RevertInternalPurchase',
                request_serializer=tarot_dot_users__pb2.CommitInternalPurchaseRequest.SerializeToString,
                response_deserializer=tarot_dot_users__pb2.CustomerTransaction.FromString,
                )
        self.RegisterReferral = channel.unary_unary(
                '/tarot.Users/RegisterReferral',
                request_serializer=tarot_dot_users__pb2.RegisterReferralRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class UsersServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateCustomer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCustomerLanguage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSpreadProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSpreadProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomerBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomerTransactions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TopUpBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitiateInternalPurchase(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommitInternalPurchase(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevertInternalPurchase(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterReferral(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UsersServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateCustomer': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCustomer,
                    request_deserializer=tarot_dot_users__pb2.CreateCustomerRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerProfile.SerializeToString,
            ),
            'GetCustomer': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomer,
                    request_deserializer=tarot_dot_users__pb2.GetCustomerRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerProfile.SerializeToString,
            ),
            'UpdateCustomerLanguage': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCustomerLanguage,
                    request_deserializer=tarot_dot_users__pb2.CustomerLanguageRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerProfile.SerializeToString,
            ),
            'CreateTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTelegramUser,
                    request_deserializer=tarot_dot_users__pb2.TelegramUser.FromString,
                    response_serializer=tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'GetTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTelegramUser,
                    request_deserializer=tarot_dot_users__pb2.GetCustomerRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'UpdateTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTelegramUser,
                    request_deserializer=tarot_dot_users__pb2.TelegramUser.FromString,
                    response_serializer=tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'UpdateSpreadProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSpreadProfile,
                    request_deserializer=tarot_dot_users__pb2.SpreadProfile.FromString,
                    response_serializer=tarot_dot_users__pb2.SpreadProfile.SerializeToString,
            ),
            'GetSpreadProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSpreadProfile,
                    request_deserializer=tarot_dot_users__pb2.GetCustomerRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.SpreadProfile.SerializeToString,
            ),
            'GetCustomerBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomerBalance,
                    request_deserializer=tarot_dot_users__pb2.GetCustomerRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerBalance.SerializeToString,
            ),
            'GetCustomerTransactions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomerTransactions,
                    request_deserializer=tarot_dot_users__pb2.GetCustomerRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerTransactions.SerializeToString,
            ),
            'TopUpBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.TopUpBalance,
                    request_deserializer=tarot_dot_users__pb2.TopUpBalanceRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerBalance.SerializeToString,
            ),
            'InitiateInternalPurchase': grpc.unary_unary_rpc_method_handler(
                    servicer.InitiateInternalPurchase,
                    request_deserializer=tarot_dot_users__pb2.InternalPurchaseRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerTransaction.SerializeToString,
            ),
            'CommitInternalPurchase': grpc.unary_unary_rpc_method_handler(
                    servicer.CommitInternalPurchase,
                    request_deserializer=tarot_dot_users__pb2.CommitInternalPurchaseRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerTransaction.SerializeToString,
            ),
            'RevertInternalPurchase': grpc.unary_unary_rpc_method_handler(
                    servicer.RevertInternalPurchase,
                    request_deserializer=tarot_dot_users__pb2.CommitInternalPurchaseRequest.FromString,
                    response_serializer=tarot_dot_users__pb2.CustomerTransaction.SerializeToString,
            ),
            'RegisterReferral': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterReferral,
                    request_deserializer=tarot_dot_users__pb2.RegisterReferralRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tarot.Users', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Users(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateCustomer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/CreateCustomer',
            tarot_dot_users__pb2.CreateCustomerRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCustomer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/GetCustomer',
            tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCustomerLanguage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/UpdateCustomerLanguage',
            tarot_dot_users__pb2.CustomerLanguageRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/CreateTelegramUser',
            tarot_dot_users__pb2.TelegramUser.SerializeToString,
            tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/GetTelegramUser',
            tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
            tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/UpdateTelegramUser',
            tarot_dot_users__pb2.TelegramUser.SerializeToString,
            tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSpreadProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/UpdateSpreadProfile',
            tarot_dot_users__pb2.SpreadProfile.SerializeToString,
            tarot_dot_users__pb2.SpreadProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSpreadProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/GetSpreadProfile',
            tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
            tarot_dot_users__pb2.SpreadProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCustomerBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/GetCustomerBalance',
            tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerBalance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCustomerTransactions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/GetCustomerTransactions',
            tarot_dot_users__pb2.GetCustomerRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerTransactions.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TopUpBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/TopUpBalance',
            tarot_dot_users__pb2.TopUpBalanceRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerBalance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitiateInternalPurchase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/InitiateInternalPurchase',
            tarot_dot_users__pb2.InternalPurchaseRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerTransaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CommitInternalPurchase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/CommitInternalPurchase',
            tarot_dot_users__pb2.CommitInternalPurchaseRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerTransaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevertInternalPurchase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/RevertInternalPurchase',
            tarot_dot_users__pb2.CommitInternalPurchaseRequest.SerializeToString,
            tarot_dot_users__pb2.CustomerTransaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterReferral(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/RegisterReferral',
            tarot_dot_users__pb2.RegisterReferralRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tarot import bot_pb2 as tarot_dot_bot__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10tarot/task.proto\x12\x05tarot\x1a\x0ftarot/bot.proto\"\xa1\x01\n\x13ScheduleTaskRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x04type\x18\x02 \x01(\x0e\x32\x0f.tarot.TaskType\x12*\n\x07payload\x18\x03 \x01(\x0b\x32\x19.tarot.SendMessageRequest\x12\x17\n\rdue_timestamp\x18\x04 \x01(\x03H\x00\x42\n\n\x08scheduleB\x07\n\x05_name\"\x92\x01\n\x14ScheduleTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\t\x12\x1d\n\x04type\x18\x04 \x01(\x0e\x32\x0f.tarot.TaskType\x12!\n\x06status\x18\x05 \x01(\x0e\x32\x11.tarot.TaskStatusB\x07\n\x05_name*\x92\x01\n\nTaskStatus\x12\x1b\n\x17TASK_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13TASK_STATUS_PENDING\x10\x01\x12\x1b\n\x17TASK_STATUS_IN_PROGRESS\x10\x02\x12\x19\n\x15TASK_STATUS_COMPLETED\x10\x03\x12\x16\n\x12TASK_STATUS_FAILED\x10\x04*c\n\x08TaskType\x12\x19\n\x15TASK_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16TASK_TYPE_SEND_MESSAGE\x10\x01\x12 \n\x1cTASK_TYPE_SEND_BATCH_MESSAGE\x10\x02\x32X\n\x0bTaskManager\x12I\n\x0cScheduleTask\x12\x1a.tarot.ScheduleTaskRequest\x1a\x1b.tarot.ScheduleTaskResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.task_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TASKSTATUS']._serialized_start=358
  _globals['_TASKSTATUS']._serialized_end=504
  _globals['_TASKTYPE']._serialized_start=506
  _globals['_TASKTYPE']._serialized_end=605
  _globals['_SCHEDULETASKREQUEST']._serialized_start=45
  _globals['_SCHEDULETASKREQUEST']._serialized_end=206
  _globals['_SCHEDULETASKRESPONSE']._serialized_start=209
  _globals['_SCHEDULETASKRESPONSE']._serialized_end=355
  _globals['_TASKMANAGER']._serialized_start=607
  _globals['_TASKMANAGER']._serialized_end=695
# @@protoc_insertion_point(module_scope)
